@@ -40,7 +40,7 @@ pip install cdk-image-pipeline
 ---
 
 
-```typescript
+```python
 import { ImagePipeline } from 'cdk-image-pipeline'
 import { Construct } from 'constructs';
 
@@ -62,7 +62,7 @@ new ImagePipeline(this, "MyImagePipeline", {
 
 By default, the infrastructure configuration will deploy EC2 instances for the build/test phases into a default VPC using the default security group. If you want to control where the instances are launched, you can specify an existing VPC `SubnetID` and a list of `SecurityGroupIds`. In the example below, a new VPC is created and referenced in the `ImagePipeline` construct object.
 
-```typescript
+```python
 import { ImagePipeline } from 'cdk-image-pipeline'
 import * as ec2 from 'aws-cdk-lib/aws-ec2';
 import { Construct } from 'constructs';
@@ -259,6 +259,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_imagebuilder
@@ -310,6 +312,10 @@ class ImagePipeline(
         :param security_groups: List of security group IDs for the Infrastructure Configuration.
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ImagePipeline.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ImagePipelineProps(
             component_documents=component_documents,
             component_names=component_names,
@@ -342,6 +348,9 @@ class ImagePipeline(
         self,
         value: typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(ImagePipeline, "image_recipe_components").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageRecipeComponents", value)
 
 
@@ -403,6 +412,23 @@ class ImagePipelineProps:
         :param security_groups: List of security group IDs for the Infrastructure Configuration.
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ImagePipelineProps.__init__)
+            check_type(argname="argument component_documents", value=component_documents, expected_type=type_hints["component_documents"])
+            check_type(argname="argument component_names", value=component_names, expected_type=type_hints["component_names"])
+            check_type(argname="argument component_versions", value=component_versions, expected_type=type_hints["component_versions"])
+            check_type(argname="argument image_recipe", value=image_recipe, expected_type=type_hints["image_recipe"])
+            check_type(argname="argument infra_config_name", value=infra_config_name, expected_type=type_hints["infra_config_name"])
+            check_type(argname="argument kms_key_alias", value=kms_key_alias, expected_type=type_hints["kms_key_alias"])
+            check_type(argname="argument parent_image", value=parent_image, expected_type=type_hints["parent_image"])
+            check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
+            check_type(argname="argument profile_name", value=profile_name, expected_type=type_hints["profile_name"])
+            check_type(argname="argument email", value=email, expected_type=type_hints["email"])
+            check_type(argname="argument image_recipe_version", value=image_recipe_version, expected_type=type_hints["image_recipe_version"])
+            check_type(argname="argument instance_types", value=instance_types, expected_type=type_hints["instance_types"])
+            check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
         self._values: typing.Dict[str, typing.Any] = {
             "component_documents": component_documents,
             "component_names": component_names,
